#!/bin/bash

#using the reads submitted to Genbank SRA
#raw readsSRR8878915
#run oyster river protocol
module load shared
module load ORP/2.2.3
module unload anaconda
source activate orp
oyster.mk main STRAND=RF \
MEM=300 \
CPU=8 \
READ1=NBS1175_Dero_MOE_1_clean.fq.gz \
READ2=NBS1175_Dero_MOE_2_clean.fq.gz \
RUNOUT=NBS1175_Dero_MOE

#targeted bait capture
#clean raw reads
#run basic quality control, which includes trimming and removing low-quality reads
bbduk.sh -Xmx20g in1=LS022_Dero_CB0JEANXX_s4_1_MY764-MY507_SL251958.fastq.gz out1=LS022_Dero_mybaits_1_clean.fq.gz in2=LS022_Dero_CB0JEANXX_s4_2_MY764-MY507_SL251958.fastq.gz out2=LS022_Dero_mybaits_2_clean.fq.gz minlen=25 qtrim=rl trimq=10 qhist=qc_plots/LS022_Dero_mybaits_qhist.txt aqhist=qc_plots/LS022_Dero_mybaits_aqhist.txt lhist=qc_plots/LS022_Dero_mybaits_readLength.txt bqhist=qc_plots/LS022_Dero_mybaits_bqhist.txt overwrite=true
#matching paired reads, and removing any paired reads that are duplicates
#remove duplicate reads
cd /Volumes/Yinptero/mybaits/2_clean_reads/
mpirun -n 4 /Applications/ParDRe-rel2.2.5/ParDRe -i LS022_Dero_mybaits_1_clean.fq.gz -p LS022_Dero_mybaits_2_clean.fq.gz -m 0 -l 20 -z 1
##now we are at the stage in which cleaned reads were submitted to Genbank
#run with raw reads downloaded from GenBank SRA SAMN11392284 files
#assemble baits based test_targets.fasta
HybPiper/reads_first.py -b test_targets.fasta -r LS022_Dero_mybaits_1_clean_NonDup.fq.gz LS022_Dero_mybaits_2_clean.NonDup.fq.gz --prefix LS022_Dero_mybaits --bwa


#Identify the ORA to identify olfactory receptors from genome, transcriptome, or assembled baits
for file in *.fasta
do
	perl or.pl -sequence "$file" -a -d --sub "$file".sub.fasta > "$file".ORs.fasta
done

#Map genome receptors to genome to get coordinates
#index the genome
gmap_build -D /../vampire_genome_mapping/ -d gmap_vampire_bat_12kmer -q 1 -k 12 /../vampire_bat_10Aug2015_WXtkA.fasta
#map the identified ORs to the g
gmap --dir=/../vampire_genome_mapping/gmap_vampire_bat_12kmer --input-buffer-size=100 -n 1 --min-identity=1 -t 8 --nosplicing -d gmap_vampire_bat_12kmer -k 12 -A --split-output=Dero_genomeCDS_ORs_functional_ORsOnly_gmap --failed-input=Dero_genomeCDS_ORs_functional_ORsOnlys_gmap.failedInput.fasta Dero_genomeCDS_ORs_functional_ORsOnly.fasta  
gmap --dir=/../vampire_genome_mapping/gmap_vampire_bat_12kmer --input-buffer-size=100 -n 1 --min-identity=1 -t 8 --nosplicing -d gmap_vampire_bat_12kmer -k 12 -A -f samse Dero_genomeCDS_ORs_functional_ORsOnly.fasta >Dero_genomeCDS_ORs_functional_ORsOnlys_gmap.sam
samtools view -Sb Dero_genomeCDS_ORs_functional_ORsOnlys_gmap.sam > Dero_genomeCDS_ORs_functional_ORsOnlys_gmap.bam
bamToBed -i Dero_genomeCDS_ORs_functional_ORsOnlys_gmap.bam > Dero_genomeCDS_ORs_functional_ORsOnlys_gmap.bed
sort-bed Dero_genomeCDS_ORs_functional_ORsOnlys_gmap.bed >Dero_genomeCDS_ORs_functional_ORsOnlys_gmap_sorted.bed

#map Sanger reads to genome to get coordinates
gmap --dir=/../vampire_genome_mapping/gmap_vampire_bat_12kmer -t 8 --min-identity=0.95 --nosplicing -d gmap_vampire_bat_12kmer -k 12 -A --split-output=Dero_haydenORs_gmap --failed-input=Dero_haydenORs_gmap.failedInput.fasta Dero_haydenORs.fasta 
gmap --dir=/../vampire_genome_mapping/gmap_vampire_bat_12kmer -t 8 --min-identity=0.95 --nosplicing -d gmap_vampire_bat_12kmer -k 12 -A -f samse Dero_haydenORs.fasta >Dero_haydenORs_gmap.sam
samtools view -Sb Dero_haydenORs_gmap.sam > Dero_haydenORs_gmap.bam
bamToBed -i Dero_haydenORs_gmap.bam > Dero_haydenORs_gmap.bed
sort-bed Dero_haydenORs_gmap.bed > Dero_haydenORs_gmap_sorted.bed

#map de novo reads to genome to get coordinates
gmap --dir=/../vampire_genome_mapping/gmap_vampire_bat_12kmer -t 8 --min-identity=0.95 --nosplicing -d gmap_vampire_bat_12kmer -k 12 -A --split-output=NBS1175_Dero_MOE.ORP_ORs_functional_ORsONLY_gmap --failed-input=NBS1175_Dero_MOE.ORP_ORs_functional_ORsONLY_gmap.failedInput.fasta NBS1175_Dero_MOE.ORP_ORs_functional_ORsONLY.fasta
gmap --dir=/../vampire_genome_mapping/gmap_vampire_bat_12kmer -t 8 --min-identity=0.95 --nosplicing -d gmap_vampire_bat_12kmer -k 12 -A -f samse NBS1175_Dero_MOE.ORP_ORs_functional_ORsONLY.fasta >NBS1175_Dero_MOE.ORP_ORs_functional_ORsONLY_gmap.sam
samtools view -Sb NBS1175_Dero_MOE.ORP_ORs_functional_ORsONLY_gmap.sam > NBS1175_Dero_MOE.ORP_ORs_functional_ORsONLY_gmap.bam
bamToBed -i NBS1175_Dero_MOE.ORP_ORs_functional_ORsONLY_gmap.bam > NBS1175_Dero_MOE.ORP_ORs_functional_ORsONLY_gmap.bed
sort-bed NBS1175_Dero_MOE.ORP_ORs_functional_ORsONLY_gmap.bed > NBS1175_Dero_MOE.ORP_ORs_functional_ORsONLY_gmap_sorted.bed

#bait capture
gmap --dir=/../vampire_genome_mapping/gmap_vampire_bat_12kmer --min-identity=0.95 -e -t 8 --nosplicing -d gmap_vampire_bat_12kmer -k 12 -A --split-output=LS022_Dero_mybaits_gmap --failed-input=LS022_Dero_mybaits_ORs_gmap.failedInput.fasta LS022_Dero_mybaits_ORs_labeled_functional.fasta
gmap --dir=/../vampire_genome_mapping/gmap_vampire_bat_12kmer --min-identity=0.95 -e -t 8 --nosplicing -d gmap_vampire_bat_12kmer -k 12 -A -f samse LS022_Dero_mybaits_ORs_labeled_functional.fasta >LS022_Dero_mybaits_ORs_gmap.sam
samtools view -Sb LS022_Dero_mybaits_ORs_gmap.sam > LS022_Dero_mybaits_ORs_gmap.bam
bamToBed -i LS022_Dero_mybaits_ORs_gmap.bam > LS022_Dero_mybaits_ORs_gmap.bed
sort-bed LS022_Dero_mybaits_ORs_gmap.bed > LS022_Dero_mybaits_ORs_gmap_sorted.bed


#make ROC plots for the mapping
#example: multiIntersectBed -header -i a.bed b.bed c.bed -names A B C
intersectBed -header -f 0.5 -wao -a Dero_genomeCDS_ORs_functional_ORsOnlys_gmap_sorted_trim.bed -b Dero_haydenORs_gmap_sorted_trim.bed >Dero_genomeCDS_v_Dero_haydenORs.bed
intersectBed -header -f 0.5 -wao -a Dero_genomeCDS_ORs_functional_ORsOnlys_gmap_sorted_trim.bed -b NBS1175_Dero_MOE.ORP_ORs_functional_ORsONLY_gmap_sorted_trim.bed >Dero_genomeCDS_v_NBS1175_Dero_MOE_ORP.bed
intersectBed -header -f 0.5 -wao -a Dero_genomeCDS_ORs_functional_ORsOnlys_gmap_sorted_trim.bed -b NBS1175_Dero_MOE_test1_1TrinityPE_ORs_functional_ORsOnlys_gmap_sorted_trim.bed >Dero_genomeCDS_v_NBS1175_Dero_MOE_test1.bed
intersectBed -header -f 0.5 -wao -a Dero_genomeCDS_ORs_functional_ORsOnlys_gmap_sorted_trim.bed -b LS022_Dero_mybaits_ORs_labeled_functional_sorted_trim.bed >Dero_genomeCDS_v_LS022_Dero_mybaits_ORs.bed

multiIntersectBed -header -cluster -i Dero_genomeCDS_ORs_functional_ORsOnlys_gmap_sorted.bed Dero_haydenORs_gmap_sorted.bed NBS1175_Dero_MOE.ORP_ORs_functional_ORsONLY_gmap_sorted.bed  LS022_Dero_mybaits_ORs_gmap_sorted.bed -names Dero_genomeCDS Dero_haydenORs Dero_genomeCDS_v_NBS1175_Dero_MOE_ORP LS022_Dero_mybaits  >vampire_multibed.bed


